@@ -95,12 +95,14 @@ delimited_index_connection::delimited_index_connection(
 
   delim_len_ = delim_.length();
 
-  size_t first_nl = find_next_newline(
+  size_t first_nl;
+  newline_type nl;
+  std::tie(first_nl, nl) = find_next_newline(
       buf[i], start, comment, skip_empty_rows, has_quoted_newlines, quote);
 
   bool single_line = first_nl == buf[i].size() - 1;
 
-  if (sz > 1 && buf[i][first_nl] != '\n') {
+  if (sz > 1 && !has_expected_line_ending(nl, buf[i][first_nl])) {
     // This first newline must not have fit in the buffer, throw error
     // suggesting a larger buffer size.
 
@@ -142,6 +144,7 @@ delimited_index_connection::delimited_index_connection(
       buf[i],
       idx_[0],
       delim_.c_str(),
+      nl,
       quote,
       comment_,
       skip_empty_rows,
@@ -182,6 +185,7 @@ delimited_index_connection::delimited_index_connection(
             buf[i],
             idx_[1],
             delim_.c_str(),
+            nl,
             quote,
             comment_,
             skip_empty_rows,
@@ -250,7 +254,7 @@ delimited_index_connection::delimited_index_connection(
 
   size_t file_size = mmap_.size();
 
-  if (!n_max_set && mmap_[file_size - 1] != '\n') {
+  if (!n_max_set && !has_expected_line_ending(nl, mmap_[file_size - 1])) {
     if (columns_ == 0 || single_line) {
       idx_[0].push_back(file_size);
       ++columns_;
@@ -272,7 +276,6 @@ delimited_index_connection::delimited_index_connection(
   }
 
 #ifdef VROOM_LOG
-#if SPDLOG_ACTIVE_LEVEL <= SPD_LOG_LEVEL_DEBUG
   auto log = spdlog::basic_logger_mt(
       "basic_logger", "logs/index_connection.idx", true);
   for (auto& i : idx_) {
@@ -282,7 +285,6 @@ delimited_index_connection::delimited_index_connection(
     SPDLOG_LOGGER_DEBUG(log, "end of idx {0:x}", (size_t)&i);
   }
   spdlog::drop("basic_logger");
-#endif
 #endif
 
   SPDLOG_DEBUG("columns: {0} rows: {1}", columns_, rows_);
